import { Box, Modal, Typography, Divider } from "@mui/material";
import CloseIcon from "@mui/icons-material/Close";
import { useEffect, useState } from "react";
import { useSelector } from "react-redux";
import { RootState } from "../../../redux/store/store";

type User = {
  id: number;
  name: string;
  email?: string;
  phone: string;
  registeredAddress?: string;
  action?: any;
};

type Props = {
  open: boolean;
  setViewModal: (value: boolean) => void;
  id?: number;
  tableType?: "admin" | "manager";
};

const style = {
  position: "absolute",
  top: "50%",
  left: "50%",
  transform: "translate(-50%, -50%)",
  width: 400,
  bgcolor: "background.paper",
  borderRadius: 2,
  boxShadow: "0px 4px 20px rgba(0, 0, 0, 0.15)",
  p: 4,
  display: "flex",
  flexDirection: "column",
  alignItems: "center",
  gap: 2,
};

export default function ViewModal({ open, setViewModal, id, tableType }: Props) {
  const adminList = useSelector((state: RootState) => state.adminReducer.admins) || [];
  const managerList = useSelector((state: RootState) => state.managerReducer.managers) || [];

  const [selectedItem, setSelectedItem] = useState<User | null>(null);

  useEffect(() => {
    if (!id || !tableType) return;

    const dataList: User[] = tableType === "admin" ? adminList : managerList;
    const item = dataList.find((user) => user.id === id);

    if (item) {
      setSelectedItem(item); // ✅ Updating selected item properly
    }
  }, [id, tableType, adminList, managerList]);

  const formattedType = tableType ? tableType.charAt(0).toUpperCase() + tableType.slice(1) : "User";

  return (
    <Modal open={open} onClose={() => setViewModal(false)} aria-labelledby="modal-title">
      <Box sx={style}>
        <Typography variant="h5" fontWeight="bold" sx={{ width: "100%" }}>
          <Box sx={{ display: "flex", justifyContent: "space-between", alignItems: "center" }}>
            <Box sx={{ flex: 1, textAlign: "center" }}>
              {selectedItem?.name ? `${selectedItem.name}'s Details` : `${formattedType} Details`}
            </Box>
            <Box onClick={() => setViewModal(false)} sx={{ cursor: "pointer", display: "flex" }}>
              <CloseIcon />
            </Box>
          </Box>
        </Typography>

        <Divider sx={{ width: "100%" }} />

        {selectedItem ? (
          <Box sx={{ width: "80%", textAlign: "left", display: "flex", flexDirection: "column", gap: 1.5 }}>
            <Typography variant="body1">
              <b>Name:</b> {selectedItem.name || "N/A"}
            </Typography>
            <Typography variant="body1">
              <b>Email:</b> {selectedItem.email || "N/A"}
            </Typography>
            <Typography variant="body1">
              <b>Phone:</b> {selectedItem.phone || "N/A"}
            </Typography>
            <Typography variant="body1">
              <b>Address:</b> {selectedItem.registeredAddress || "N/A"}
            </Typography>
          </Box>
        ) : (
          <Typography align="center">No {formattedType} found with this ID</Typography>
        )}
      </Box>
    </Modal>
  );
}
